#ifndef I2CRTC_H
#define I2CRTC_H

#define RTC_READ     0xD1 
#define RTC_WRITE    0xD0 


typedef struct {
    unsigned SECONDS:4;
    unsigned TEN_SECONDS:3;
    unsigned CH:1;
    }tSeconds;

typedef struct {
    unsigned MINUTES:4;
    unsigned TEN_MINUTES:3;
    unsigned ZERO_BIT:1;
    }tMinutes;

typedef struct {
    unsigned HOURS:4;
    unsigned TEN_HR:2;
	unsigned MODE12_24:1;
	unsigned ZERO_BIT:1;
    }tHours24;

typedef struct {
    unsigned HOURS:4;
    unsigned TEN_HR:1;
	unsigned AM_PM:1;
	unsigned MODE12_24:1;
	unsigned ZERO_BIT:1;
    }tHours12;

typedef struct {
    unsigned DAY:3;
	unsigned ZERO_5BITS:5;
    }tDay;

typedef struct {
    unsigned DATE:4;
	unsigned TEN_DATE:2;
	unsigned ZERO_2BITS:2;
    }tDate;

typedef struct {
    unsigned MONTH:4;
	unsigned TEN_MONTH:1;
	unsigned ZERO_3BITS:3;
    }tMonth;

typedef struct {
    unsigned YEAR:4;
	unsigned TEN_YEAR:4;
    }tYear;

typedef struct {
    unsigned RS0:1;
	unsigned RS1:1;
	unsigned ZERO_2BITS:2;
	unsigned SQEW:1;
	unsigned ZERO_2BITS_2:2;
	unsigned OUT:4;
    }tControl;

typedef union {
unsigned char seconds8b;
tSeconds secondsFields;
}tuSeconds;

typedef union {
unsigned char minutes8b;
tMinutes minutesFields;
}tuMinutes;

typedef union {
unsigned char hours8b;
tHours24 hours24Fields;
tHours12 hours12Fields;
}tuHours;

typedef union {
unsigned char day8b;
tDay dayFields;
}tuDay;

typedef union {
unsigned char date8b;
tDate dateFields;
}tuDate;

typedef union {
unsigned char month8b;
tMonth monthFields;
}tuMonth;

typedef union {
unsigned char year8b;
tYear yearFields;
}tuYear;

union uControl{
unsigned char control8b;
tControl controlFields;
};

typedef struct
{
	tuSeconds 	sec;
	tuMinutes	min;
	tuHours    hours;
	tuDay		day;
	tuDate		date;
	tuMonth		month;
	tuYear		year;
}tTimeDate;



// functions declaration or prototypes
void startRTC(void);
void initializeRTC(tTimeDate* pTimeDate );
void readRTC(tTimeDate* pTimeDate); 
void setRTCAdressTo(unsigned char address);
void writeControl(unsigned char value);
unsigned char readControl(void);

#endif