#include <p18f4520.h>
#include <i2c.h>
#include "I2CRTC.h"


/********************************************************************
*     Function Name:    startRTC                    				*
*     Return Value:     no return value			                    *
*     Parameters:       no parameters						        *
*     Description:      start the RTC bu putting 0 into the CH bit  *
********************************************************************/
void startRTC()  
{
	IdleI2C();                      // ensure module is idle
  	StartI2C();                     // initiate START condition
	WriteI2C( RTC_WRITE );				// slave RTC
	WriteI2C( 0);
	WriteI2C( 0);					// put CH bit to 0
	StopI2C(); 
}

/********************************************************************
*     Function Name:    initializeRTC                    			*
*     Return Value:     no return value			                    *
*     Parameters:       a pointer to a tTimeDate structure          *
*     Description:      initialize the RTC by writing the correct   *
*                       time and date contained int the tTimeDate   *
*  						structure									*
********************************************************************/
void initializeRTC(tTimeDate* pTimeDate)  
{
	IdleI2C();                      // ensure module is idle
  	StartI2C();                     // initiate START condition
	WriteI2C( RTC_WRITE );				// slave RTC
	WriteI2C( 0);					// starting at address 0 into the the slave
	WriteI2C(pTimeDate->sec.seconds8b );
	WriteI2C(pTimeDate->min.minutes8b );
	WriteI2C(pTimeDate->hours.hours8b );
	WriteI2C(pTimeDate->day.day8b );
	WriteI2C(pTimeDate->date.date8b );
	WriteI2C(pTimeDate->month.month8b );
	WriteI2C(pTimeDate->year.year8b );
	
	StopI2C(); 
	
}
/********************************************************************
*     Function Name:    readRTC					                    *
*     Return Value:     no return value			                    *
*     Parameters:       a pointer to a tTimeDate structure			*
*                       bytes.                                      *
*     Description:      read the RTC time and date fields through   *
*                       I2C                                         *  
********************************************************************/
void setRTCAdressTo(unsigned char address)  
{
	IdleI2C();                      // ensure module is idle
  	StartI2C();                     // initiate START condition
	WriteI2C( RTC_WRITE );				// slave RTC
	WriteI2C( address);
	StopI2C();
}

/********************************************************************
*     Function Name:    readRTC					                    *
*     Return Value:     no return value			                    *
*     Parameters:       a pointer to a tTimeDate structure			*
*                       bytes.                                      *
*     Description:      read the RTC time and date fields through   *
*                       I2C                                         *  
********************************************************************/
void readRTC( tTimeDate* pTimeDate)  
{

	IdleI2C();                      // ensure module is idle
  	StartI2C();                     // initiate START condition
	WriteI2C( RTC_READ );				// slave RTC
						// starting at address 0 into the the slave
	pTimeDate->sec.seconds8b = ReadI2C();
	AckI2C();
	pTimeDate->min.minutes8b = ReadI2C();
	AckI2C();
	pTimeDate->hours.hours8b = ReadI2C();
	AckI2C();
	pTimeDate->day.day8b = ReadI2C();
	AckI2C();
	pTimeDate->date.date8b = ReadI2C();
	AckI2C();
	pTimeDate->month.month8b = ReadI2C();
	AckI2C();
	pTimeDate->year.year8b = ReadI2C();
	NotAckI2C();
	
	
	StopI2C(); 
	
}
/********************************************************************
*     Function Name:    readRTC					                    *
*     Return Value:     no return value			                    *
*     Parameters:       a pointer to a tTimeDate structure			*
*                       bytes.                                      *
*     Description:      read the RTC time and date fields through   *
*                       I2C                                         *  
********************************************************************/
void writeControl(unsigned char value)
{
	

	IdleI2C();                      // ensure module is idle
  	StartI2C();                     // initiate START condition
	WriteI2C( RTC_WRITE );				// slave RTC
	WriteI2C(0x7);
	WriteI2C( value);
	StopI2C();

	//setRTCAdressTo(0x00);

}
/********************************************************************
*     Function Name:    readRTC					                    *
*     Return Value:     the value of the CONTROL register           *
*     Parameters:       a pointer to a tTimeDate structure			*
*                       bytes.                                      *
*     Description:      read the RTC time and date fields through   *
*                       I2C                                         *  
********************************************************************/
unsigned char readControl()
{
unsigned char control;

	IdleI2C();                      // ensure module is idle
  	StartI2C();                     // initiate START condition
	WriteI2C( RTC_WRITE );				// slave RTC
	WriteI2C(0x7);
	StopI2C();

  	IdleI2C();                      // ensure module is idle
  	StartI2C();   
	WriteI2C( RTC_READ );				// slave RTC
									// starting at address 0x7 into the the slave
	control = ReadI2C();
	NotAckI2C();
	StopI2C();

	return(control);

}